From akpm@osdl.org Wed Aug 17 15:33:43 2005
Message-Id: <200508172229.j7HMTu9X014951@shell0.pdx.osdl.net>
Subject: PCI: Support PCM PM CAP version 3
To: greg@kroah.com
From: Daniel Ritz <daniel.ritz@gmx.ch>
Date: Wed, 17 Aug 2005 15:32:19 -0700

- support PCI PM CAP version 3 (as defined in PCI PM Interface Spec v1.2)

- pci/probe.c sets the PM state initially to 4 which is D3cold.  add a
  PCI_UNKNOWN

- minor cleanups

Signed-off-by: Daniel Ritz <daniel.ritz@gmx.ch>
Signed-off-by: Andrew Morton <akpm@osdl.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 drivers/pci/pci.c   |   12 +++++-------
 drivers/pci/probe.c |    2 +-
 include/linux/pci.h |    1 +
 3 files changed, 7 insertions(+), 8 deletions(-)

--- gregkh-2.6.orig/drivers/pci/pci.c	2005-08-18 01:36:33.000000000 -0700
+++ gregkh-2.6/drivers/pci/pci.c	2005-08-18 23:51:51.000000000 -0700
@@ -294,7 +294,7 @@ pci_set_power_state(struct pci_dev *dev,
 		return -EIO; 
 
 	pci_read_config_word(dev,pm + PCI_PM_PMC,&pmc);
-	if ((pmc & PCI_PM_CAP_VER_MASK) > 2) {
+	if ((pmc & PCI_PM_CAP_VER_MASK) > 3) {
 		printk(KERN_DEBUG
 		       "PCI: %s has unsupported PM cap regs version (%u)\n",
 		       pci_name(dev), pmc & PCI_PM_CAP_VER_MASK);
@@ -302,12 +302,10 @@ pci_set_power_state(struct pci_dev *dev,
 	}
 
 	/* check if this device supports the desired state */
-	if (state == PCI_D1 || state == PCI_D2) {
-		if (state == PCI_D1 && !(pmc & PCI_PM_CAP_D1))
-			return -EIO;
-		else if (state == PCI_D2 && !(pmc & PCI_PM_CAP_D2))
-			return -EIO;
-	}
+	if (state == PCI_D1 && !(pmc & PCI_PM_CAP_D1))
+		return -EIO;
+	else if (state == PCI_D2 && !(pmc & PCI_PM_CAP_D2))
+		return -EIO;
 
 	pci_read_config_word(dev, pm + PCI_PM_CTRL, &pmcsr);
 
--- gregkh-2.6.orig/drivers/pci/probe.c	2005-08-18 01:36:33.000000000 -0700
+++ gregkh-2.6/drivers/pci/probe.c	2005-08-18 23:51:51.000000000 -0700
@@ -584,7 +584,7 @@ static int pci_setup_device(struct pci_d
 		 dev->vendor, dev->device, class, dev->hdr_type);
 
 	/* "Unknown power state" */
-	dev->current_state = 4;
+	dev->current_state = PCI_UNKNOWN;
 
 	/* Early fixups, before probing the BARs */
 	pci_fixup_device(pci_fixup_early, dev);
--- gregkh-2.6.orig/include/linux/pci.h	2005-08-18 01:36:33.000000000 -0700
+++ gregkh-2.6/include/linux/pci.h	2005-08-18 23:51:51.000000000 -0700
@@ -75,6 +75,7 @@ typedef int __bitwise pci_power_t;
 #define PCI_D2		((pci_power_t __force) 2)
 #define PCI_D3hot	((pci_power_t __force) 3)
 #define PCI_D3cold	((pci_power_t __force) 4)
+#define PCI_UNKNOWN	((pci_power_t __force) 5)
 #define PCI_POWER_ERROR	((pci_power_t __force) -1)
 
 /*
